@@ -1,6 +1,6 @@
 """
 Generated using https://signald.org/protocol.json
-Version: '0.21.1'=
+Version: '0.22.1'=
 """
 
 from .error import SignaldException
@@ -117,6 +117,14 @@ class ProofRequiredError(SignaldException):
     retry_after: int
 
 
+class SignalServerError(SignaldException):
+    """
+    indicates signald received an http 500 status code from the server
+    """
+
+    message: str
+
+
 class UnregisteredUserError(SignaldException):
     message: str
     e164_number: str
@@ -242,6 +250,7 @@ __all__ = [
     "AuthorizationFailedError",
     "SQLError",
     "ProofRequiredError",
+    "SignalServerError",
     "UnregisteredUserError",
     "OwnProfileKeyDoesNotExistError",
     "GroupPatchNotAcceptedError",
